@@ -135,7 +135,7 @@ def get_parser():
     parser.add_argument("-j", "--jobs",
         type    = int,
         help    = "Number of Jobs to be used.",
-        default = getenv("JOBS", mp.cpu_count())
+        default = getenv("JOBS", max(mp.cpu_count(), 4))
     )
     parser.add_argument("-u", "--user",
         action  = "store_true",
