@@ -7,6 +7,7 @@ import re
 import json
 import multiprocessing as mp
 from   functools import partial
+import traceback
 
 # imports - module imports
 from pipupgrade.commands.helper import (
@@ -70,7 +71,17 @@ ARGUMENTS = dict(
 
 @cli.command
 def command(**ARGUMENTS):
-    return _command(**ARGUMENTS)
+    try:
+        return _command(**ARGUMENTS)
+    except Exception:
+        cli.echo()
+
+        traceback_str = traceback.format_exc()
+        cli.echo(traceback_str)
+
+        cli.echo(cli_format("""\
+An error occured while performing the above command. This could be an issue with
+"pipupgrade". Kindly post an issue at https://github.com/achillesrasquinha/pipupgrade/issues""", cli.RED))
 
 def to_params(kwargs):
     class O(object):
@@ -136,13 +147,11 @@ def _command(*args, **kwargs):
         cli.echo("%s upto date." % cli_format(package, cli.CYAN),
             file = file_)
     else:
-        requirements = sequencify(a.requirements) or [ ]
-        pipfile      = sequencify(a.pipfile)      or [ ]
-
+        requirements = sequencify(a.requirements or [])
+        pipfile      = sequencify(a.pipfile or [])
+        
         if a.project:
             project		 = sequencify(a.project)
-            # requirements = a.requirements or [ ]
-            # pipfile      = a.pipfile      or [ ]
 
             logger.info("Detecting projects and its dependencies...")
             
@@ -293,4 +302,4 @@ def _command(*args, **kwargs):
 
                         cli.echo(cli_format(message, cli.GREEN), file = file_)
                     else:
-                        response.raise_for_status()
\ No newline at end of file
+                        response.raise_for_status()
